Key

Struct Key 

pub struct Key { /* private fields */ }
A key identifying a Value.

Implementations

Source

impl Key

pub const fn from_static(b: &'static [u8]) -> Key

Create a new Key from static bytes without copying.

pub const fn from_static_str(b: &'static str) -> Key

Create a new Key from a &'static str without copying.

pub fn as_str(&self) -> Option<&str>

Read the key as a str slice if it can be parsed as a UTF8 string.

pub fn as_bytes(&self) -> &[u8]

Read the key as a byte slice.

pub fn inner(&self) -> &Bytes

Read the inner Bytes struct.

pub fn as_str_lossy(&self) -> Cow<'_, str>

Read the key as a lossy UTF8 string with String::from_utf8_lossy.

pub fn into_string(self) -> Option<String>

Convert the key to a UTF8 string, if possible.

pub fn into_bytes(self) -> Bytes

Read the inner bytes making up the key.

pub fn as_bytes_str(&self) -> Option<StrInner<Bytes>>

Parse and return the key as a Str without copying the inner contents.

pub fn cluster_hash(&self) -> u16

Hash the key to find the associated cluster hash slot.

pub fn cluster_owner<C>(&self, client: &C) -> Option<Server>
where C: ClientLike,

Read the host:port of the cluster node that owns the key if the client is clustered and the cluster state is known.

pub fn take(&mut self) -> Bytes

Replace this key with an empty byte array, returning the bytes from the original key.

pub fn convert<K>(self) -> Result<K, Error>
where K: FromKey,

Attempt to convert the key to any type that implements FromKey.

See the Value::convert documentation for more information.